<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Грешка израза</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation>Tамна тема</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Једноставан режим</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Научни режим</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Дипин Калкулатор</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Дипин Калкулатор је једноставан и лак за коришћење рачунарски калкулатор. Подржава сабирање, одузимање, множење и дељење.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Грешка израза</translation>
    </message>
</context>
</TS>